




libname input "[Insert folder where data are stored]" access=readonly;
libname output "[Insert folder where you will save new dataset]";
options nofmterr;



/**STEP 1: EXPORT NARRATIVES AND CREATE SIDS FLAG**/
data _part1;
	set input.OriginalFileName;/*input file name*/
run;

*create table of free text narratives;
proc sql;
create table _part2 as
	select subjectid, child_3_20, openresponse
	from _part1
	order by subjectid;
quit;

**export free text narratives as excel spreadsheet;
proc export 
  data=work._part2
  dbms=xlsx 
  outfile="[Insert folder where you will save narratives]\narratives.xlsx" 
  replace;
run;

**import excel file with sids flag;
proc import out= WORK.narratives 
            datafile= "[Insert folder where coded narratives are stored]\narratives.xlsx" 
            dbms=EXCEL REPLACE;
     range="Allnarratives$"; 
     getnames=YES;
     mixed=NO;
     scantext=YES;
     usedate=YES;
     scantime=YES;
run;

proc contents data=narratives varnum; run;

proc sql;
create table _part3 as
	select a.*, b.flag_sids as SIDS
		from _part1 as a left join narratives as b
			on a.subjectid=b.subjectid & a.child_3_20=b.child_3_20;
quit;

proc contents data=_part3 varnum; run;

proc freq data=_part3;
	tables child_3_20 SIDS/missing;
run;


proc freq data=_part3;
	tables respdeath_final*SIDS/missing;
run;

**export final analytic file with sids flag;
data output.vafinal;
	set _part3;
run;

proc freq data=output.vafinal;
	tables sids/missing;
run;



/**STEP 2: CODE DEMOGRAPHIC VARIABLES NEEDED FOR ADDITIONAL ANALYSIS**/
proc sort data=input.vafinal out=temp;
	by sids;
run;

proc contents data=temp varnum; run;

**recode sids variable and create variable for cause of death;
data temp;
set temp;

	if sids=. then sids2=.;/*missing*/
	else if sids=1 then sids2=1;/*yes*/
	else if sids=0 then sids2=2;/*no*/

	if sids=1 then cod=1;/*SIDS*/ 
	else if respdeath_final=1 then cod=2;/*Respiratory*/
	else cod=3;/*Other*/

run;

proc freq data=temp;
	tables sids sids2 cod cod*sids2 cod*respdeath_final/missing;
run;

**check demographic variables needed;
proc univariate data=temp;
	var dthaged dthagew dthagem brth_wgt;
		histogram;
run;
**58 missing age in weeks and month. non missing age in days;

proc freq data=temp;
	tables childgender fthed mthed fthocc mthocc fthlive mthlive whrborn whrdie whrdie_sp child_1_11/missing;
run;
**99 unknown gender. 733 missing for child_1_11;

**compute age in months and weeks for missing values;
data temp;
set temp;

	if dthagew=. then do;
	dthagew=dthaged/7;
	end;
	format dthagew 8.0;

	if dthagem=. then do;
 	dthagem=dthaged/30.5;
 	end;
 	format dthagem 8.2;

 run;

proc univariate data=temp;
	var dthaged dthagew dthagem brth_wgt;
		histogram;
run;

proc means data=temp min max mean lclm uclm median range;
	var dthaged dthagew dthagem brth_wgt;
run;

**recode variables;
**age and gender;
data temp1;
set temp;

**birth weight;
	if brth_wgt=. then brthwgt=.;
	else if brth_wgt lt 1500 then brthwgt=1;/*< 1500*/
	else if 1500 le brth_wgt lt 2500 then brthwgt=2;/*1500 to <2500*/
	else if 2500 le brth_wgt lt 4000 then brthwgt=3;/*2500 to <4000*/
	else if brth_wgt ge 4000 then brthwgt=4;/*>= 4000*/

**age at death in months;
	**7 cat;
	if dthagem=. then agem1=.;/*missing*/
	else if dthagem lt 1 then agem1=1;/*< 1 mo*/
	else if 1 le dthagem lt 2 then agem1=2;/*1-2 mo*/
	else if 2 le dthagem lt 3 then agem1=3;/*2-3 mo*/
	else if 3 le dthagem lt 4 then agem1=4;/*3-4 mo*/
	else if 4 le dthagem lt 5 then agem1=5;/*4-5 mo*/
	else if 5 le dthagem lt 6 then agem1=6;/*5-6 mo*/
	else if dthagem ge 6 then agem1=7;/*> 6 mo*/

	**3 cat;
	if dthagem=. then agem2=.;/*missing*/
	else if dthagem lt 2 then agem2=1;/*4days-2 mo*/
	else if 2 le dthagem lt 4 then agem2=2;/*2-4 mo*/
	else if 4 le dthagem lt 6 then agem2=3;/*4-6 mo*/
	else if dthagem ge 6 then agem2=4;/*> 6 mo*/

	**2 cat;
	if dthagem=. then agem3=.;/*missing*/
	else if dthagem lt 2 then agem3=1;/*4days-2 mo*/
	else agem3=2;/*2+*/

**sex;
	if childgender in (., 8) then gender=.;/*missing*/
	else if childgender=1 then gender=1;/*male*/
	else if childgender=2 then gender=2;/*female*/

**where born;
	if whrborn in (8, 9, .) then whrborn2=.;/*unknown, refused, missing*/
	else if whrborn in (1, 4, 5) then whrborn2=1;/*hospital/other health facility/other*/
	else if whrborn in (3, 6) then whrborn2=2;/*home/enroute to hospital*/

**where die;
	if whrdie in (., 8, 9) then whrdie2=.;/*unknown or refused to answer, missing*/
	else if whrdie in (1, 6) then whrdie2=1;/*health facility*/
	else if whrdie in (3, 5) then whrdie2=2;/*home or enroute to hospital*/
	
	if whrdie_sp in ("Malipole clinic",
						"Matelo fist level Hospital",
						"Matero Reference2",
						"Pearl of Health Hospital") then whrdie2=1;/*health facility*/
	if whrdie_sp="On the way home from the health facility" then whrdie2=2;/*on the way home*/

run;

proc freq data=temp1;
	tables brth_wgt brthwgt agem1 agem2 childgender gender whrborn whrborn2 whrdie whrdie2 /missing;
run;

proc freq data=temp1;
	tables agem1 /missing;
	by sids;
run;


proc freq data=temp1;
	tables whrdie2*sids/missing;
run;

**education and occupation;
data temp2;
set temp1;

**education (mother & father);
	**5 cat, mother;
	if mthed =. then educm1=.;
	else if mthed=1 then educm1=1;/*none*/
	else if mthed in (2, 3) then educm1=2;/*some primary or completed primary*/
	else if mthed in (4, 5) then educm1=3;/*some secondary or completed secondary*/
	else if mthed in (6, 7) then educm1=4;/*some postsecondary or completed postsecondary*/
	else if mthed=8 then educm1=5;/*unknown*/

	**4 cat, mother;
	if mthed in (., 8) then educm2=.;/*missing or unknown*/
	else if mthed=1 then educm2=1;/*none*/
	else if mthed in (2, 3) then educm2=2;/*some primary or completed primary*/
	else if mthed in (4, 5) then educm2=3;/*some secondary or completed secondary*/
	else if mthed in (6, 7) then educm2=4;/*some postsecondary or completed postsecondary*/

	**2 cat, mother;
	if mthed in (., 8) then educm3=.;/*missing*/
	else if mthed in (1, 2, 3) then educm3=1;/*none or completed primary*/
	else if mthed in (4, 5, 6, 7) then educm3=2;/*some secondary to completed postsecondary*/

	**5 cat, father;
	if fthed =. then educf1=.;
	else if fthed=1 then educf1=1;/*none*/
	else if fthed in (2, 3) then educf1=2;/*some primary or completed primary*/
	else if fthed in (4, 5) then educf1=3;/*some secondary or completed secondary*/
	else if fthed in (6, 7) then educf1=4;/*some postsecondary or completed postsecondary*/
	else if fthed =8 then educf1=5;/*unknown*/

	**4 cat, father;
	if fthed in (., 8) then educf2=.;/*missing or unknwon*/
	else if fthed=1 then educf2=1;/*none*/
	else if fthed in (2, 3) then educf2=2;/*some primary or completed primary*/
	else if fthed in (4, 5) then educf2=3;/*some secondary or completed secondary*/
	else if fthed in (6, 7) then educf2=4;/*some postsecondary or completed postsecondary*/

	**2 cat, father;
	if fthed in(., 8) then educf3=.;/*missing*/
	else if fthed in (1, 2, 3) then educf3=1;/*none or completed primary*/
	else if fthed in (4, 5, 6, 7) then educf3=2;/*some secondary to completed postsecondary*/

**occupation (mother & father);	
	**3 cat, mother;
	if mthocc =. then occum1=.;/*unknown*/
	else if mthocc in (1, 2) then occum1=1;/*employed; salaried and self employed*/
	else if mthocc = 3 then occum1=2;/*unemployed*/
	else if mthocc=8 then occum1=3;/*unknown*/

	**2 cat, mother;
	if mthocc in (., 8) then occum2=.;/*missing or unknown*/
	else if mthocc in (1, 2) then occum2=1;/*employed; salaried and self employed*/
	else if mthocc = 3 then occum2=2;/*unemployed*/

	**3 cat, father;
	if fthocc=. then occuf1=.;/*unknown*/
	else if fthocc in (1, 2) then occuf1=1;/*employed; salaried and self employed*/
	else if fthocc = 3 then occuf1=2;/*unemployed*/
	else if fthocc=8 then occuf1=3;/*unknown*/

	**2 cat, father;
	if fthocc in (., 8) then occuf2=.;/*unknown*/
	else if fthocc in (1, 2) then occuf2=1;/*employed; salaried and self employed*/
	else if fthocc = 3 then occuf2=2;/*unemployed*/
run;

proc freq data=temp2;
	tables mthed educm1 educm2 educm3 fthed educf1 educf2 educf3 mthocc occum1 occum2 fthocc occuf1 occuf2/missing;
run;

**domestic composition;
data temp3;
set temp2;

**living arrangements;	
	if mthlive in (., 8) then livem=.;/*missing or unknown*/
	else if mthlive=1 then livem=1;/*yes*/
	else if mthlive=2 then livem=2;/*no*/

	if fthlive in (., 8) then livef=.;/*missing or unknown*/
	else if fthlive=1 then livef=1;/*yes*/
	else if fthlive=2 then livef=2;/*no*/

**both parents together;
	if livem=. or livef=. then bothp=.;/*missing*/
	else if livem=1 and livef=1 then bothp=1;/*yes*/
	else bothp=2;/*no*/

**single mothers;
	if livem=. or livef=. then singlem=.;/*missing*/
	else if livem=1 and livef=2 then singlem=1;/*yes*/
	else singlem=2;/*no*/

**single fathers;
	if livem=. or livef=. then singlef=.;/*missing*/
	else if livem=2 and livef=1 then singlef=1;/*yes*/
	else singlef=2;/*no*/

run;

proc freq data=temp3;
	tables livem livef bothp singlem singlef /missing;
run;
**1 single father;

**create variables for season, time of day, month of death;

**time and date of death;
proc freq data=temp1;
	tables dthtimhr1 dod /missing;
run;

data temp4;
set temp3;

**time of day;
	if  dthtimhr1 < '06:00't then tod=1;/*night*/
	else if dthtimhr1 <'12:00't then tod=2;/*morning*/
	else if dthtimhr1 <'18:00't then tod=3;/*afternoon*/
	else tod=4;/*evening*/

	if tod in (1, 2) then tod2=1;/*night and morning*/
	else if tod in (3, 4) then tod2=2;/*afternoon and evening*/

**day of week;
	weekday=weekday(dod);

	**weekend vs weekday;
	if weekday=. then weekend=.;
	else if weekday in (1, 7) then weekend=1;/*weekend: sunday, saturday*/
	else weekend=2;/*weekday: monday, tuesday, wednesday, thursday, friday*/

**month;
	month=month(dod);

**season;
	if month=. then season1=.;/*missing*/
	else if month in (11, 12, 1, 2, 3, 4) then season1=1;/*hot and rainy*/
	else if month in (5, 6, 7, 8) then season1=2;/*cold and dry*/
	else if month in (9, 10) then season1=3;/*hot and dry*/


	if month=. then season2=.;/*missing*/
	else if month in (11, 12, 1, 2, 3, 4) then season2=1;/*Rainy/summer*/
	else if month in (5, 6, 7, 8, 9, 10) then season2=2;/*Dry/winter*/

**year;
	year=year(dod);

run;

proc freq data=temp4;
	tables tod tod2 weekday weekend month season1 season2 year /missing;
run;

**create variables for household composition;

**NB: whliva= # Adults (>=18 years and older), whlivc1= # Children (>=5 years to < 18 years), whlivc2= # Children (>=1 year to < 5 years)
	whlivi= # Infants (< 1 year of age);

proc freq data=temp4;
	tables whliva whlivc1 whlivc2 whlivi;
run;

proc print data=temp4 (obs=20);
	var subjectid whliva whlivc1 whlivc2 whlivi;
run;

proc contents data=temp1 varnum; run;

data temp5;
set temp4;

**household composition;
	hsecomp=whliva + whlivc1 + whlivc2 + whlivi;

	**5 cat;
	if hsecomp=. then nmem1=.;/*missing*/
	else if 1 le hsecomp le 2 then nmem1=1;/*1-2*/
	else if 2 lt hsecomp le 4 then nmem1=2;/*3-4*/
	else if 4 lt hsecomp le 6 then nmem1=3;/*5-6*/
	else if 6 lt hsecomp le 8 then nmem1=4;/*7-8*/
	else if hsecomp gt 8 then nmem1=5;/*9+ */

	**3 cat;
	if hsecomp=. then nmem2=.;/*missing*/
	else if 1 le hsecomp le 3 then nmem2=1;/*1-3*/
	else if 3 lt hsecomp le 5 then nmem2=2;/*4-5*/
	else if hsecomp gt 5 then nmem2=3;/*6+ */

**number of children in household;
	chldn= whlivc1 + whlivc2 + whlivi;

	if chldn=. then parity=.;
	else if chldn=1 then parity=1;/*1*/
	else if chldn=2 then parity=2;/*2*/
	else if chldn=3 then parity=3;/*3*/
	else if chldn ge 4 then parity=4;/*4+*/

	**under 5;
	under5= whlivc2 + whlivi;

	if under5=. then under5cat=.;
	else if under5=1 then under5cat=1;
	else if under5=2 then under5cat=2;
	else if under5=3 then under5cat=3;
	else if under5 ge 4 then under5cat=4;

**has siblings;
	if chldn=. then sib=.;
	else if chldn > 1 then sib=1;/*yes*/
	else sib=2;/*no*/

**primiparous mothers;
	primip=2;
	if whlivc1=0 and whlivc2=0 and whlivi=1 then primip=1;

run;

proc print data=temp5 (obs=20);
	var whliva whlivc1 whlivc2 whlivi hsecomp 
			nmem1 nmem2 chldn under5 parity sib primip;
run;

proc freq data=temp5;
	tables hsecomp nmem1 nmem2 chldn parity under5 under5cat sib primip /missing nopercent;
run;

**export final analytic datafile;
data output.finalsids_new;
	set temp5;
run;

proc contents data=output.finalsids_new varnum; run;

proc freq data=output.finalsids_new;
tables brthwgt agem1 agem2 agem3 gender educm3 educf3 occum2 occuf2 livem livef bothp singlem singlef
		tod tod2 weekday weekend month season1 season2 year nmem1 nmem2 parity primip/missing;
run;


/**STEP 3: ANALYZE CODED DATA, PRODUCE DESCRIPTIVE STATISTICS AND REGRESSION ANALYSIS RESULTS**/
proc contents data=input.finalsids_new varnum; run;

data temp;
	set input.finalsids_new;

	if parity=. then parity2=.;
	else if parity in (1, 2) then parity2=1;
	else if parity in (3, 4) then parity2=2;

	if parity=. then parity3=.;
	else if parity in (1, 2, 3) then parity3=1;
	else if parity = 4 then parity3=2;
run;

proc freq data=temp;
	tables parity parity2 parity3/missing;
run;

proc freq data=temp;
	tables (parity2 parity3)*sids2/missing norow nopercent;
run;

**table 1: demographic characteristics of BIDs;

proc means data=temp min max mean stddev lclm uclm median;
	var dthagem brth_wgt hsecomp;
run;

proc freq data=temp;
	tables brthwgt gender educf1 educm1 occuf1 occum1 parity livef livem bothp sib whrdie2/missing;
run;

**table 2: cause of death;
proc freq data=temp;
	tables respdeath_final sids cod/missing;
run;
 
**table 3: representative suspected suid narratives;
proc print data=temp (obs=20);
	var subjectid cod openresponse dthagem;
	where cod=1;
run;

**table 4: representative respiratory narratives;
proc print data=temp (obs=20);
	var subjectid cod openresponse dthagem;
	where cod=2;
run;

**table 5: representative other cod narratives;
proc print data=temp (obs=20);
	var subjectid cod openresponse dthagem;
	where cod=3;
run;

**table 6: population characteristics of suspected SUID cases;
proc means data=temp min max mean median stddev lclm uclm;
	class sids;
	var dthagem brth_wgt hsecomp;
run;

proc freq data=temp;
	tables brthwgt gender sib educm2 occum2 parity livef livem bothp singlem/missing;
	by sids;
run;

**figure 1: peak age of sids;
proc freq data=temp;
	tables agem1/missing;
	by sids;
run;

**figure 2: weekday;
proc freq data=temp;
	tables weekday/missing;
	by sids;
run;

**figure 3: time of death;
proc freq data=temp;
	tables tod/missing;
	by sids;
run;

**figure 4: month of death;
proc freq data=temp;
	tables month/missing;
	by sids;
run;

**figure 5: season of death;
proc freq data=temp;
	tables season1/missing;
	by sids;
run;

**table 7: crude associations of factors independently associated with sids;

proc freq data=temp;
	tables (agem1 gender sib educm3 occum2 singlem educf3 occuf2 parity livef bothp tod weekday weekend season1)*sids2/missing norow nopercent;
run;

proc means data=temp min max mean median stddev lclm uclm;
	class sids;
	var dthagem brth_wgt hsecomp;
run;

**infant age;
proc logistic data=temp descending;
	class agem1(ref="1")/param=ref;
	model sids=agem1/risklimits;
run;

**infant gender;
proc logistic data=temp descending;
	class childgender(ref="1")/param=ref;
	model sids=childgender/risklimits;
run;

**siblings;
proc logistic data=temp descending;
	class sib(ref="2")/param=ref;
	model sids=sib/risklimits;
run;

**maternal education;
proc logistic data=temp descending;
	class educm3(ref="2")/param=ref;
	model sids=educm3/risklimits;
run;

**maternal occupation;
proc logistic data=temp descending;
	class occum2(ref="1")/param=ref;
	model sids=occum2/risklimits;
run;

**number of children in household;
proc logistic data=temp descending;
	class parity3(ref="1")/param=ref;
	model sids=parity3/risklimits;
run;

**father lives in household;
proc logistic data=temp descending;
	class livef(ref="2")/param=ref;
	model sids=livef/risklimits;
run;

**time of day;
proc logistic data=temp descending;
	class tod(ref="3")/param=ref;
	model sids=tod/risklimits;
run;

**season;
proc logistic data=temp descending;
	class season1(ref="1")/param=ref;
	model sids=season1/risklimits;
run;


**table 7: multivariable analysis;
proc logistic data=temp descending;
	class agem1(ref="1") 
		childgender(ref="1")
		sib(ref="2")
		educm3(ref="2")
		occum2(ref="1")
		parity3(ref="1")
		livef(ref="2")
		tod(ref="3")
		season1(ref="1")/param=ref;
	 model sids = agem1 childgender sib educm3 occum2 parity3 livef tod season1/ risklimits ;
run;
